@@ -113,7 +113,7 @@ types_converter_dict = {
             "varchar": "String",
             "interval": "String",
             "character varying": "String",
-            "boolean": "UInt8",
+            "boolean": "String",
             "timestamp": "Datetime",
             "timestamp without time zone": "Datetime",
             "time without time zone": "String",
